"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PubSub = void 0;
const tslib_1 = require("tslib");
const buffer_1 = require("buffer");
const uuid_1 = require("uuid");
class PubSub {
    constructor(ipfs, namespace) {
        this.ipfs = ipfs;
        this.namespace = namespace;
    }
    getTopic(topic) {
        return `${this.namespace}/${topic}`;
    }
    encode(data) {
        return JSON.stringify(data);
    }
    decode(data) {
        return JSON.parse(data);
    }
    subscribe(topic, listener) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            yield this.ipfs.pubsub.subscribe(this.getTopic(topic), (message) => {
                listener({
                    from: message.from,
                    data: this.decode(buffer_1.Buffer.from(message.data).toString())
                });
            });
        });
    }
    handleRequest(method, listener) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            this.subscribe(method, (msg) => (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
                const data = msg.data;
                listener(data.args, (data) => this.publish(data.reply, data));
            }));
        });
    }
    request(method, args, timeout = 1000) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const reply = (0, uuid_1.v4)();
            return new Promise((resolve, reject) => {
                this.subscribe(reply, (msg) => resolve(msg.data));
                setTimeout(() => reject('timeout'), timeout);
                this.publish(method, { reply, args });
            });
        });
    }
    publish(topic, data) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            yield this.ipfs.pubsub.publish(this.getTopic(topic), buffer_1.Buffer.from(this.encode(data)));
        });
    }
    unsubscribe(topic) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            yield this.ipfs.pubsub.unsubscribe(this.getTopic(topic));
        });
    }
}
exports.PubSub = PubSub;
//# sourceMappingURL=pubsub.js.map