import type { IPFS } from "ipfs-core";
import { CID } from "multiformats/cid";
import { Options as LRUOptions } from "lru-cache";
import { PubSub } from "./pubsub";
export interface Link {
    [name: string]: CID | undefined;
}
export declare class Shard<T = any> {
    private ipfs;
    cid: CID;
    private context?;
    private constructor();
    private static encode;
    private static decode;
    static from<T = any>(ipfs: IPFS, cid: CID, context?: {
        namespace: string;
        store: Store;
    }): Promise<Shard<T>>;
    static create<T = any>(ipfs: IPFS, data: T, context?: {
        namespace: string;
        store: Store;
    }): Promise<Shard<T>>;
    get(): Promise<T | null>;
    private refreshStore;
    set(data: T): Promise<void>;
    /**
     * **Links are EXPERIMENTAL**
     */
    links(): Promise<Link>;
    /**
     * **Links are EXPERIMENTAL**
     */
    addLink(name: string, cid: CID): Promise<void>;
    /**
     * **Links are EXPERIMENTAL**
     */
    rmLink(cid: CID): Promise<void>;
}
export declare class Store {
    ipfs: IPFS;
    namespace: string;
    private pubsub;
    private cache;
    constructor(ipfs: IPFS, namespace: string, pubsub: PubSub, cache?: LRUOptions<string, CID>);
    start(): Promise<void>;
    private getDHTKey;
    emitUpdate(key: string, value: CID): Promise<void>;
    set<T = any>(key: string, data: T): Promise<Shard<T>>;
    getFromDHT<T = any>(key: string, timeout?: number): Promise<Shard<T>>;
    getFromPubSub<T = any>(key: string, timeout?: number): Promise<Shard<T>>;
    get<T = any>(key: string, timeout?: number): Promise<Shard<T>>;
}
